@@ -24,28 +24,17 @@
 #include "db.h"
 #include "package.h"
 
-struct __pmconflict_t {
-	char *package1;
-	char *package2;
-	char *reason;
-};
+alpm_conflict_t *_alpm_conflict_dup(const alpm_conflict_t *conflict);
+void _alpm_conflict_free(alpm_conflict_t *conflict);
+alpm_list_t *_alpm_innerconflicts(alpm_handle_t *handle, alpm_list_t *packages);
+alpm_list_t *_alpm_outerconflicts(alpm_db_t *db, alpm_list_t *packages);
+alpm_list_t *_alpm_db_find_fileconflicts(alpm_handle_t *handle,
+		alpm_list_t *upgrade, alpm_list_t *remove);
 
-struct __pmfileconflict_t {
-	char *target;
-	pmfileconflicttype_t type;
-	char *file;
-	char *ctarget;
-};
+void _alpm_fileconflict_free(alpm_fileconflict_t *conflict);
 
-pmconflict_t *_alpm_conflict_new(const char *package1, const char *package2, const char *reason);
-pmconflict_t *_alpm_conflict_dup(const pmconflict_t *conflict);
-void _alpm_conflict_free(pmconflict_t *conflict);
-alpm_list_t *_alpm_innerconflicts(alpm_list_t *packages);
-alpm_list_t *_alpm_outerconflicts(pmdb_t *db, alpm_list_t *packages);
-alpm_list_t *_alpm_db_find_fileconflicts(pmdb_t *db, pmtrans_t *trans,
-					 alpm_list_t *upgrade, alpm_list_t *remove);
-
-void _alpm_fileconflict_free(pmfileconflict_t *conflict);
+const alpm_file_t *_alpm_filelist_contains(alpm_filelist_t *filelist,
+		const char *name);
 
 #endif /* _ALPM_CONFLICT_H */
 
