@@ -26,6 +26,9 @@
 #if defined(HAVE_SYS_STATVFS_H)
 #include <sys/statvfs.h>
 #endif
+#if defined(HAVE_SYS_TYPES_H)
+#include <sys/types.h>
+#endif
 
 #include "alpm.h"
 
@@ -39,14 +42,14 @@ typedef struct __alpm_mountpoint_t {
 	char *mount_dir;
 	size_t mount_dir_len;
 	/* storage for additional disk usage calculations */
-	long blocks_needed;
-	long max_blocks_needed;
+	blkcnt_t blocks_needed;
+	blkcnt_t max_blocks_needed;
 	enum mount_used_level used;
 	int read_only;
 	FSSTATSTYPE fsp;
 } alpm_mountpoint_t;
 
-int _alpm_check_diskspace(pmtrans_t *trans, pmdb_t *db_local);
+int _alpm_check_diskspace(alpm_handle_t *handle);
 
 #endif /* _ALPM_DISKSPACE_H */
 
