@@ -394,6 +394,11 @@ static int curl_download_internal(struct dload_payload *payload,
 	CURL *curl = get_libcurl_handle(handle);
 	handle->pm_errno = 0;
 
+	/* make sure these are NULL */
+	FREE(payload->tempfile_name);
+	FREE(payload->destfile_name);
+	FREE(payload->content_disp_name);
+
 	payload->tempfile_openmode = "wb";
 	if(!payload->remote_name) {
 		STRDUP(payload->remote_name, get_filename(payload->fileurl),
@@ -436,8 +441,8 @@ static int curl_download_internal(struct dload_payload *payload,
 
 	curl_easy_setopt(curl, CURLOPT_WRITEDATA, localf);
 
-	/* ignore any SIGPIPE signals- these may occur if our FTP socket dies or
-	 * something along those lines. Store the old signal handler first. */
+	/* Ignore any SIGPIPE signals. With libcurl, these shouldn't be happening,
+	 * but better safe than sorry. Store the old signal handler first. */
 	mask_signal(SIGPIPE, SIG_IGN, &orig_sig_pipe);
 	mask_signal(SIGINT, &inthandler, &orig_sig_int);
 
