@@ -845,7 +845,7 @@ static int download_files(alpm_handle_t *handle, alpm_list_t **deltas)
 
 							CALLOC(dpayload, 1, sizeof(*dpayload), RET_ERR(handle, ALPM_ERR_MEMORY, -1));
 							STRDUP(dpayload->remote_name, delta->delta, RET_ERR(handle, ALPM_ERR_MEMORY, -1));
-							dpayload->max_size = delta->download_size;
+							dpayload->max_size = delta->delta_size;
 
 							files = alpm_list_add(files, dpayload);
 						}
@@ -896,6 +896,8 @@ static int download_files(alpm_handle_t *handle, alpm_list_t **deltas)
 					if(ret != -1) {
 						break;
 					}
+					FREE(payload->fileurl);
+					payload->unlink_on_fail = 0;
 				}
 				if(ret == -1) {
 					errors++;
@@ -1137,7 +1139,7 @@ int _alpm_sync_commit(alpm_handle_t *handle, alpm_list_t **data)
 	}
 
 	/* check available disk space */
-	if(handle->checkspace) {
+	if(handle->checkspace && !(trans->flags & ALPM_TRANS_FLAG_DBONLY)) {
 		EVENT(handle, ALPM_EVENT_DISKSPACE_START, NULL, NULL);
 
 		_alpm_log(handle, ALPM_LOG_DEBUG, "checking available disk space\n");
