@@ -1,7 +1,7 @@
 /*
  *  util.c
  *
- *  Copyright (c) 2006-2011 Pacman Development Team <pacman-dev@archlinux.org>
+ *  Copyright (c) 2006-2012 Pacman Development Team <pacman-dev@archlinux.org>
  *  Copyright (c) 2002-2006 by Judd Vinet <jvinet@zeroflux.org>
  *  Copyright (c) 2005 by Aurelien Foret <orelien@chez.com>
  *  Copyright (c) 2005 by Christian Hamar <krics@linuxforum.hu>
@@ -381,7 +381,6 @@ int _alpm_rmrf(const char *path)
 	int errflag = 0;
 	struct dirent *dp;
 	DIR *dirp;
-	char name[PATH_MAX];
 	struct stat st;
 
 	if(_alpm_lstat(path, &st) == 0) {
@@ -401,9 +400,10 @@ int _alpm_rmrf(const char *path)
 				return 1;
 			}
 			for(dp = readdir(dirp); dp != NULL; dp = readdir(dirp)) {
-				if(dp->d_ino) {
-					sprintf(name, "%s/%s", path, dp->d_name);
+				if(dp->d_name) {
 					if(strcmp(dp->d_name, "..") != 0 && strcmp(dp->d_name, ".") != 0) {
+						char name[PATH_MAX];
+						sprintf(name, "%s/%s", path, dp->d_name);
 						errflag += _alpm_rmrf(name);
 					}
 				}
@@ -622,7 +622,7 @@ int _alpm_ldconfig(alpm_handle_t *handle)
 		snprintf(line, PATH_MAX, "%ssbin/ldconfig", handle->root);
 		if(access(line, X_OK) == 0) {
 			char *argv[] = { "ldconfig", NULL };
-			_alpm_run_chroot(handle, "/sbin/ldconfig", argv);
+			return _alpm_run_chroot(handle, "/sbin/ldconfig", argv);
 		}
 	}
 
@@ -1000,7 +1000,7 @@ cleanup:
 	{
 		int ret = b->ret;
 		FREE(b->line);
-		memset(b, 0, sizeof(b));
+		memset(b, 0, sizeof(struct archive_read_buffer));
 		return ret;
 	}
 }
@@ -1085,7 +1085,7 @@ off_t _alpm_strtoofft(const char *line)
 	errno = 0;
 
 	/* we are trying to parse bare numbers only, no leading anything */
-	if(line[0] < '0' || line[0] > '9') {
+	if(!isdigit((unsigned char)line[0])) {
 		return (off_t)-1;
 	}
 	result = strtoull(line, &end, 10);
