@@ -93,21 +93,26 @@ static int rpmvercmp(const char *a, const char *b)
 	int ret = 0;
 
 	/* easy comparison to see if versions are identical */
-	if(strcmp(a, b) == 0) return(0);
+	if(strcmp(a, b) == 0) return 0;
 
 	str1 = strdup(a);
 	str2 = strdup(b);
 
-	one = str1;
-	two = str2;
+	one = ptr1 = str1;
+	two = ptr2 = str2;
 
 	/* loop through each version segment of str1 and str2 and compare them */
-	while(*one && *two) {
-		while(*one && !isalnum((int)*one)) one++;
-		while(*two && !isalnum((int)*two)) two++;
+	while (*one && *two) {
+		while (*one && !isalnum((int)*one)) one++;
+		while (*two && !isalnum((int)*two)) two++;
 
 		/* If we ran to the end of either, we are finished with the loop */
-		if(!(*one && *two)) break;
+		if (!(*one && *two)) break;
+
+		/* If the separator lengths were different, we are also finished */
+		if ((one - ptr1) != (two - ptr2)) {
+			return (one - ptr1) < (two - ptr2) ? -1 : 1;
+		}
 
 		ptr1 = one;
 		ptr2 = two;
@@ -115,13 +120,13 @@ static int rpmvercmp(const char *a, const char *b)
 		/* grab first completely alpha or completely numeric segment */
 		/* leave one and two pointing to the start of the alpha or numeric */
 		/* segment and walk ptr1 and ptr2 to end of segment */
-		if(isdigit((int)*ptr1)) {
-			while(*ptr1 && isdigit((int)*ptr1)) ptr1++;
-			while(*ptr2 && isdigit((int)*ptr2)) ptr2++;
+		if (isdigit((int)*ptr1)) {
+			while (*ptr1 && isdigit((int)*ptr1)) ptr1++;
+			while (*ptr2 && isdigit((int)*ptr2)) ptr2++;
 			isnum = 1;
 		} else {
-			while(*ptr1 && isalpha((int)*ptr1)) ptr1++;
-			while(*ptr2 && isalpha((int)*ptr2)) ptr2++;
+			while (*ptr1 && isalpha((int)*ptr1)) ptr1++;
+			while (*ptr2 && isalpha((int)*ptr2)) ptr2++;
 			isnum = 0;
 		}
 
@@ -209,7 +214,7 @@ static int rpmvercmp(const char *a, const char *b)
 cleanup:
 	free(str1);
 	free(str2);
-	return(ret);
+	return ret;
 }
 
 /** Compare two version strings and determine which one is 'newer'.
@@ -235,15 +240,15 @@ int SYMEXPORT alpm_pkg_vercmp(const char *a, const char *b)
 
 	/* ensure our strings are not null */
 	if(!a && !b) {
-		return(0);
+		return 0;
 	} else if(!a) {
-		return(-1);
+		return -1;
 	} else if(!b) {
-		return(1);
+		return 1;
 	}
 	/* another quick shortcut- if full version specs are equal */
 	if(strcmp(a, b) == 0) {
-		return(0);
+		return 0;
 	}
 
 	/* Parse both versions into [epoch:]version[-release] triplets. We probably
@@ -266,7 +271,7 @@ int SYMEXPORT alpm_pkg_vercmp(const char *a, const char *b)
 
 	free(full1);
 	free(full2);
-	return(ret);
+	return ret;
 }
 
 /* vim: set ts=2 sw=2 noet: */
