@@ -22,28 +22,29 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <limits.h> /* PATH_MAX */
 
 #include <alpm.h>
 #include <alpm_list.h>
 
 #define BASENAME "cleanupdelta"
 
+alpm_handle_t *handle = NULL;
+
 static void cleanup(int signum) {
-	if(alpm_release() == -1) {
-		fprintf(stderr, "error releasing alpm: %s\n", alpm_strerrorlast());
+	if(handle && alpm_release(handle) == -1) {
+		fprintf(stderr, "error releasing alpm\n");
 	}
 
 	exit(signum);
 }
 
-static void output_cb(pmloglevel_t level, const char *fmt, va_list args)
+static void output_cb(alpm_loglevel_t level, const char *fmt, va_list args)
 {
 	if(strlen(fmt)) {
 		switch(level) {
-			case PM_LOG_ERROR: printf("error: "); break;
-			case PM_LOG_WARNING: printf("warning: "); break;
-			//case PM_LOG_DEBUG: printf("debug: "); break;
+			case ALPM_LOG_ERROR: printf("error: "); break;
+			case ALPM_LOG_WARNING: printf("warning: "); break;
+			//case ALPM_LOG_DEBUG: printf("debug: "); break;
 			default: return;
 		}
 		vprintf(fmt, args);
@@ -55,7 +56,7 @@ static void checkpkgs(alpm_list_t *pkglist)
 {
 	alpm_list_t *i, *j;
 	for(i = pkglist; i; i = alpm_list_next(i)) {
-		pmpkg_t *pkg = alpm_list_getdata(i);
+		alpm_pkg_t *pkg = alpm_list_getdata(i);
 		alpm_list_t *unused = alpm_pkg_unused_deltas(pkg);
 		for(j = unused; j; j = alpm_list_next(j)) {
 			char *delta = alpm_list_getdata(j);
@@ -65,19 +66,18 @@ static void checkpkgs(alpm_list_t *pkglist)
 	}
 }
 
-static void checkdbs(char *dbpath, alpm_list_t *dbnames) {
-	char syncdbpath[PATH_MAX];
-	pmdb_t *db = NULL;
+static void checkdbs(alpm_list_t *dbnames) {
+	alpm_db_t *db = NULL;
 	alpm_list_t *i;
+	const alpm_siglevel_t level = ALPM_SIG_DATABASE | ALPM_SIG_DATABASE_OPTIONAL;
 
 	for(i = dbnames; i; i = alpm_list_next(i)) {
-		char *dbname = alpm_list_getdata(i);
-		snprintf(syncdbpath, PATH_MAX, "%s/sync/%s", dbpath, dbname);
-		db = alpm_db_register_sync(dbname);
+		const char *dbname = alpm_list_getdata(i);
+		db = alpm_db_register_sync(handle, dbname, level);
 		if(db == NULL) {
-			fprintf(stderr, "error: could not register sync database (%s)\n",
-					alpm_strerrorlast());
-			return;
+			fprintf(stderr, "error: could not register sync database '%s' (%s)\n",
+					dbname, alpm_strerror(alpm_errno(handle)));
+			continue;
 		}
 		checkpkgs(alpm_db_get_pkgcache(db));
 	}
@@ -93,7 +93,8 @@ static void usage(void) {
 
 int main(int argc, char *argv[])
 {
-	char *dbpath = DBPATH;
+	const char *dbpath = DBPATH;
+	enum _alpm_errno_t err;
 	int a = 1;
 	alpm_list_t *dbnames = NULL;
 
@@ -117,17 +118,16 @@ int main(int argc, char *argv[])
 		usage();
 	}
 
-	if(alpm_initialize() == -1) {
-		fprintf(stderr, "cannot initialize alpm: %s\n", alpm_strerrorlast());
-		return(1);
+	handle = alpm_initialize(ROOTDIR, dbpath, &err);
+	if(!handle) {
+		fprintf(stderr, "cannot initialize alpm: %s\n", alpm_strerror(err));
+		return 1;
 	}
 
 	/* let us get log messages from libalpm */
-	alpm_option_set_logcb(output_cb);
+	alpm_option_set_logcb(handle, output_cb);
 
-	alpm_option_set_dbpath(dbpath);
-
-	checkdbs(dbpath,dbnames);
+	checkdbs(dbnames);
 	alpm_list_free(dbnames);
 
 	cleanup(0);
