@@ -38,12 +38,12 @@ self.option["SyncFirst"] = ["pacman"]
 self.args = "-Su"
 
 self.addrule("PACMAN_RETCODE=0")
-self.addrule("PKG_EXIST=pacman")
 self.addrule("PKG_VERSION=pacman|1.0-2")
 self.addrule("PKG_EXIST=glibc")
-self.addrule("PKG_VERSION=glibc|2.15-1")
 self.addrule("PKG_EXIST=curl")
-self.addrule("PKG_VERSION=curl|7.22-1")
 self.addrule("PKG_EXIST=libarchive")
-self.addrule("PKG_VERSION=libarchive|2.8.5-1")
+# TODO: when SyncFirst recursive comes back, re-enable these
+#self.addrule("PKG_VERSION=glibc|2.15-1")
+#self.addrule("PKG_VERSION=curl|7.22-1")
+#self.addrule("PKG_VERSION=libarchive|2.8.5-1")
 self.addrule("PKG_EXIST=zlib")
